<?php
/**
 * Alyssa's Blog functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Alyssas Blog
 */

if ( ! defined( '_S_VERSION' ) ) {
	// Replace the version number of the theme on each release.
	define( '_S_VERSION', '1.0.0' );
}

if ( ! function_exists( 'alyssas_blog_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function alyssas_blog_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on Alyssa\'s Blog, use a find and replace
		 * to change 'alyssas-blog' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'alyssas-blog', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );

		// This theme uses wp_nav_menu() in one location.
		register_nav_menus(
			array(
				'menu-1' => esc_html__( 'Primary', 'alyssas-blog' ),
			)
		);

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support(
			'html5',
			array(
				'search-form',
				'comment-form',
				'comment-list',
				'gallery',
				'caption',
				'style',
				'script',
			)
		);

		// Set up the WordPress core custom background feature.
		add_theme_support(
			'custom-background',
			apply_filters(
				'alyssas_blog_custom_background_args',
				array(
					'default-color' => 'ffffff',
					'default-image' => '',
				)
			)
		);

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		/**
		 * Add support for core custom logo.
		 *
		 * @link https://codex.wordpress.org/Theme_Logo
		 */
		add_theme_support(
			'custom-logo',
			array(
				'height'      => 250,
				'width'       => 250,
				'flex-width'  => true,
				'flex-height' => true,
			)
		);
	}
endif;
add_action( 'after_setup_theme', 'alyssas_blog_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function alyssas_blog_content_width() {
	// This variable is intended to be overruled from themes.
	// Open WPCS issue: {@link https://github.com/WordPress-Coding-Standards/WordPress-Coding-Standards/issues/1043}.
	// phpcs:ignore WordPress.NamingConventions.PrefixAllGlobals.NonPrefixedVariableFound
	$GLOBALS['content_width'] = apply_filters( 'alyssas_blog_content_width', 640 );
}
add_action( 'after_setup_theme', 'alyssas_blog_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */


function alyssas_blog_widgets_init() {
	
	register_sidebar(
		array(
			'name'          => esc_html__( 'Right Sidebar', 'alyssas-blog' ),
			'id'            => 'right-sidebar',
			'description'   => esc_html__( 'Add widgets here.', 'alyssas-blog' ),
			'before_widget' => '<div id="%1$s" class="widget %2$s">',
			'after_widget'  => '</div>',
			'before_title'  => '<div class="sidebar-title"><h3 class="widget-title">',
			'after_title'   => '</h3></div>',
		)
	);
	register_sidebar(
		array(
			'name'          => esc_html__( 'Footer 1', 'alyssas-blog' ),
			'id'            => 'footer-1',
			'description'   => esc_html__( 'Add widgets here.', 'alyssas-blog' ),
			'before_widget' => '<div id="%1$s" class="widget %2$s category-widget">',
			'after_widget'  => '</div>',
			'before_title'  => '<div class="ft-wd-title"> <h4>',
			'after_title'   => '</h4></div>',
		)
	);
	register_sidebar(
		array(
			'name'          => esc_html__( 'Footer 2', 'alyssas-blog' ),
			'id'            => 'footer-2',
			'description'   => esc_html__( 'Add widgets here.', 'alyssas-blog' ),
			'before_widget' => '<div id="%1$s" class="widget %2$s footer-logo">',
			'after_widget'  => '</div>',
			'before_title'  => '<div class="ft-wd-title"> <h4>',
			'after_title'   => '</h4></div>',
		)
	);
	register_sidebar(
		array(
			'name'          => esc_html__( 'Footer 3', 'alyssas-blog' ),
			'id'            => 'footer-3',
			'description'   => esc_html__( 'Add widgets here.', 'alyssas-blog' ),
			'before_widget' => '<div id="%1$s" class="widget %2$s ">',
			'after_widget'  => '</div>',
			'before_title'  => '<div class="ft-wd-title"> <h4>',
			'after_title'   => '</h4></div>',
		)
	);
	register_sidebar(
		array(
			'name'          => esc_html__( 'Insta Feeds', 'alyssas-blog' ),
			'id'            => 'insta-feeds',
			'description'   => esc_html__( 'Add widgets here.', 'alyssas-blog' ),
			'before_widget' => '<div id="%1$s" class="widget insta-widget %2$s ">',
			'after_widget'  => '</div>',
		)
	);
	
	register_sidebar(
		array(
			'name'          => esc_html__( 'Profile Widget', 'alyssas-blog' ),
			'id'            => 'profile-widget',
			'description'   => esc_html__( 'Add widgets here.', 'alyssas-blog' ),
		)
	);
	
}
add_action( 'widgets_init', 'alyssas_blog_widgets_init' );

/**
 * Load Ripple Core Files
 */
require get_template_directory() . '/ripplethemes/ripple-core-files.php';


